Density, distribution function, quantile function and random generation for
the power law distribution with shape equal to shape and scale equal to
scale.
dpowerlaw(x, shape = 1, scale = 1)ppowerlaw(q, shape = 1, scale = 1)
qpowerlaw(p, shape = 1, scale = 1)
rpowerlaw(n, shape = 1, scale = 1)
dpowerlaw gives the density, ppowerlaw gives the distribution function,
qpowerlaw gives the quantile function, and rpowerlaw generates random
deviates.
vector of quantiles.
parameter of shape.
parameter of scale.
vector of probabilities.
number of observations.
The density function of the power law distribution is $$f(t) = \theta a^\theta (a+t)^{-\theta-1}$$ where \(\theta\) is the shape parameter, and \(a\) the scale parameter.